# -*- encoding : utf-8 -*-
# Lists of character replacements like ASCII and HTML entities
module Chars2Remove
  
  # List with internation chars and their ASCII replacement 
  CHARS = {
  "¡" => "",
  "&" => "",
  "¢" => "",
  "£" => "",
  "¤" => "",
  "¥" => "",
  "¦" => "",
  "§" => "",
  "¨" => "",
  "©" => "(C)",
  "ª" => "",
  "«" => "<",
  "¬" => "-",
  "­" => "-",
  "®" => "(R)",
  "¯" => "",
  "°" => "",
  "±" => "",
  "²" => "",
  "³" => "",
  "´" => "",
  "µ" => "n",
  "¶" => "",
  "·" => "",
  "¸" => "",
  "¹" => "",
  "º" => "",
  "»" => ">",
  "¼" => "",
  "½" => "",
  "¾" => "",
  "¿" => "?",
  "Ä" => "Ae",
  "À" => "A",
  "Á" => "A",
  "Â" => "A",
  "Ã" => "A",
  "Å" => "A",
  "Æ" => "Ae",
  "Ç" => "C",
  "È" => "E",
  "É" => "E",
  "Ê" => "E",
  "Ë" => "E",
  "Ì" => "I",
  "Í" => "I",
  "Î" => "I",
  "Ï" => "I",
  "Ð" => "D",
  "Ñ" => "N",
  "Ö" => "Oe",
  "Ò" => "O",
  "Ó" => "O",
  "Ô" => "O",
  "Õ" => "O",
  "×" => "x",
  "Ø" => "Oe",
  "Ü" => "Ue",
  "Ù" => "U",
  "Ú" => "U",
  "Û" => "U",
  "Ý" => "y",
  "Þ" => "p",
  "ä" => "ae",
  "ö" => "oe",
  "ü" => "ue",
  "ß" => "ss",
  "à" => "a",
  "á" => "a",
  "â" => "a",
  "ã" => "a",
  "å" => "a",
  "æ" => "ae",
  "ç" => "c",
  "è" => "e",
  "é" => "e",
  "ê" => "e",
  "ë" => "e",
  "ì" => "i",
  "í" => "i",
  "î" => "i",
  "ï" => "i",
  "ð" => "o",
  "ñ" => "n",
  "ò" => "o",
  "ó" => "o",
  "ô" => "o",
  "õ" => "o",
  "÷" => "x",
  "ø" => "o",
  "ù" => "u",
  "ú" => "u",
  "û" => "u",
  "ý" => "y",
  "þ" => "y",
  "ÿ" => "y"
  }


   
   # These charaters mustn't be removed in HTML mode!
   # All HTML Entities
   ENTITIES = {
     'Â' => {:html => '&Acirc;'     , :dec => '&#194;'  , :hex => '&#x00C2;' },
     'â' => {:html => '&acirc;'     , :dec => '&#226;'  , :hex => '&#x00E2;' },
     '´' => {:html => '&acute;'     , :dec => '&#180;'  , :hex => '&#x00B4;' },
     'Æ' => {:html => '&AElig;'     , :dec => '&#198;'  , :hex => '&#x00C6;' },
     'æ' => {:html => '&aelig;'     , :dec => '&#230;'  , :hex => '&#x00E6;' },
     'À' => {:html => '&Agrave;'    , :dec => '&#192;'  , :hex => '&#x00C0;' },
     'à' => {:html => '&agrave;'    , :dec => '&#224;'  , :hex => '&#x00E0;' },
     'ℵ' => {:html => '&alefsym;'   , :dec => '&#8501;' , :hex => '&#x2135;' },
     'Α' => {:html => '&Alpha;'     , :dec => '&#913;'  , :hex => '&#x0391;' },
     'α' => {:html => '&alpha;'     , :dec => '&#945;'  , :hex => '&#x03B1;' },
     '∧' => {:html => '&and;'       , :dec => '&#8743;' , :hex => '&#x2227;' },
     '∠' => {:html => '&ang;'       , :dec => '&#8736;' , :hex => '&#x2220;' },
     'Å' => {:html => '&Aring;'     , :dec => '&#197;'  , :hex => '&#x00C5;' },
     'å' => {:html => '&aring;'     , :dec => '&#229;'  , :hex => '&#x00E5;' },
     '≈' => {:html => '&asymp;'     , :dec => '&#8776;' , :hex => '&#x2248;' },
     'Ã' => {:html => '&Atilde;'    , :dec => '&#195;'  , :hex => '&#x00C3;' },
     'ã' => {:html => '&atilde;'    , :dec => '&#227;'  , :hex => '&#x00E3;' },
     'Ä' => {:html => '&Auml;'      , :dec => '&#196;'  , :hex => '&#x00C4;' },
     'ä' => {:html => '&auml;'      , :dec => '&#228;'  , :hex => '&#x00E4;' },
     '„' => {:html => '&bdquo;'     , :dec => '&#8222;' , :hex => '&#x201E;' },
     'Β' => {:html => '&Beta;'      , :dec => '&#914;'  , :hex => '&#x0392;' },
     'β' => {:html => '&beta;'      , :dec => '&#946;'  , :hex => '&#x03B2;' },
     '¦' => {:html => '&brvbar;'    , :dec => '&#166;'  , :hex => '&#x00A6;' },
     '•' => {:html => '&bull;'      , :dec => '&#8226;' , :hex => '&#x2022;' },
     '∩' => {:html => '&cap;'       , :dec => '&#8745;' , :hex => '&#x2229;' },
     'Ç' => {:html => '&Ccedil;'    , :dec => '&#199;'  , :hex => '&#x00C7;' },
     'ç' => {:html => '&ccedil;'    , :dec => '&#231;'  , :hex => '&#x00E7;' },
     '¸' => {:html => '&cedil;'     , :dec => '&#184;'  , :hex => '&#x00B8;' },
     '¢' => {:html => '&cent;'      , :dec => '&#162;'  , :hex => '&#x00A2;' },
     'Χ' => {:html => '&Chi;'       , :dec => '&#935;'  , :hex => '&#x03A7;' },
     'χ' => {:html => '&chi;'       , :dec => '&#967;'  , :hex => '&#x03C7;' },
     'ˆ' => {:html => '&circ;'      , :dec => '&#710;'  , :hex => '&#x02C6;' },
     '♣' => {:html => '&clubs;'     , :dec => '&#9827;' , :hex => '&#x2663;' },
     '≅' => {:html => '&cong;'      , :dec => '&#8773;' , :hex => '&#x2245;' },
     '©' => {:html => '&copy;'      , :dec => '&#169;'  , :hex => '&#x00A9;' },
     '↵' => {:html => '&crarr;'     , :dec => '&#8629;' , :hex => '&#x21B5;' },
     '∪' => {:html => '&cup;'       , :dec => '&#8746;' , :hex => '&#x222A;' },
     '¤' => {:html => '&curren;'    , :dec => '&#164;'  , :hex => '&#x00A4;' },
     '‡' => {:html => '&Dagger;'    , :dec => '&#8225;' , :hex => '&#x2021;' },
     '†' => {:html => '&dagger;'    , :dec => '&#8224;' , :hex => '&#x2020;' },
     '⇓' => {:html => '&dArr;'      , :dec => '&#8659;' , :hex => '&#x21D3;' },
     '↓' => {:html => '&darr;'      , :dec => '&#8595;' , :hex => '&#x2193;' },
     '°' => {:html => '&deg;'       , :dec => '&#176;'  , :hex => '&#x00B0;' },
     'Δ' => {:html => '&Delta;'     , :dec => '&#916;'  , :hex => '&#x0394;' },
     'δ' => {:html => '&delta;'     , :dec => '&#948;'  , :hex => '&#x03B4;' },
     '♦' => {:html => '&diams;'     , :dec => '&v#9830;', :hex => '&#x2666;' },
     '÷' => {:html => '&divide;'    , :dec => '&#247;'  , :hex => '&#x00F7;' },
     'É' => {:html => '&Eacute;'    , :dec => '&#201;'  , :hex => '&#x00C9;' },
     'é' => {:html => '&eacute;'    , :dec => '&#233;'  , :hex => '&#x00E9;' },
     'Ê' => {:html => '&Ecirc;'     , :dec => '&#202;'  , :hex => '&#x00CA;' },
     'ê' => {:html => '&ecirc;'     , :dec => '&#234;'  , :hex => '&#x00EA;' },
     'È' => {:html => '&Egrave;'    , :dec => '&#200;'  , :hex => '&#x00C8;' },
     'è' => {:html => '&egrave;'    , :dec => '&#232;'  , :hex => '&#x00E8;' },
     '∅' => {:html => '&empty;'     , :dec => '&#8709;' , :hex => '&#x2205;' },
     'Ε' => {:html => '&Epsilon;'   , :dec => '&#917;'  , :hex => '&#x0395;' },
     'ε' => {:html => '&epsilon;'   , :dec => '&#949;'  , :hex => '&#x03B5;' },
     '≡' => {:html => '&equiv;'     , :dec => '&#8801;' , :hex => '&#x2261;' },
     'Η' => {:html => '&Eta;'       , :dec => '&#919;'  , :hex => '&#x0397;' },
     'η' => {:html => '&eta;'       , :dec => '&#951;'  , :hex => '&#x03B7;' },
     'Ð' => {:html => '&ETH;'       , :dec => '&#208;'  , :hex => '&#x00D0;' },
     'ð' => {:html => '&eth;'       , :dec => '&#240;'  , :hex => '&#x00F0;' },
     'Ë' => {:html => '&Euml;'      , :dec => '&#203;'  , :hex => '&#x00CB;' },
     'ë' => {:html => '&euml;'      , :dec => '&#235;'  , :hex => '&#x00EB;' },
     '€' => {:html => '&euro;'      , :dec => '&#8364;' , :hex => '&#x20AC;' },
     '∃' => {:html => '&exist;'     , :dec => '&#8707;' , :hex => '&#x2203;' },
     'ƒ' => {:html => '&fnof;'      , :dec => '&#402;'  , :hex => '&#x0192;' },
     '∀' => {:html => '&forall;'    , :dec => '&#8704;' , :hex => '&#x2200;' },
     '½' => {:html => '&frac12;'    , :dec => '&#189;'  , :hex => '&#x00BD;' },
     '¼' => {:html => '&frac14;'    , :dec => '&#188;'  , :hex => '&#x00BC;' },
     '¾' => {:html => '&frac34;'    , :dec => '&#190;'  , :hex => '&#x00BE;' },
     'Γ' => {:html => '&Gamma;'     , :dec => '&#915;'  , :hex => '&#x0393;' },
     'γ' => {:html => '&gamma;'     , :dec => '&#947;'  , :hex => '&#x03B3;' },
     '≥' => {:html => '&ge;'        , :dec => '&#8805;' , :hex => '&#x2265;' },
     '⇔' => {:html => '&hArr;'      , :dec => '&#8660;' , :hex => '&#x21D4;' },
     '↔' => {:html => '&harr;'      , :dec => '&#8596;' , :hex => '&#x2194;' },
     '♥' => {:html => '&hearts;'    , :dec => '&#9829;' , :hex => '&#x2665;' },
     '…' => {:html => '&hellip;'    , :dec => '&#8230;' , :hex => '&#x2026;' },
     'Í' => {:html => '&Iacute;'    , :dec => '&#205;'  , :hex => '&#x00CD;' },
     'í' => {:html => '&iacute;'    , :dec => '&#237;'  , :hex => '&#x00ED;' },
     'Î' => {:html => '&Icirc;'     , :dec => '&#206;'  , :hex => '&#x00CE;' },
     'î' => {:html => '&icirc;'     , :dec => '&#238;'  , :hex => '&#x00EE;' },
     '¡' => {:html => '&iexcl;'     , :dec => '&#161;'  , :hex => '&#x00A1;' },
     'Ì' => {:html => '&Igrave;'    , :dec => '&#204;'  , :hex => '&#x00CC;' },
     'ì' => {:html => '&igrave;'    , :dec => '&#236;'  , :hex => '&#x00EC;' },
     'ℑ' => {:html => '&image;'     , :dec => '&#8465;' , :hex => '&#x2111;' },
     '∞' => {:html => '&infin;'     , :dec => '&#8734;' , :hex => '&#x221E;' },
     '∫' => {:html => '&int;'       , :dec => '&#8747;' , :hex => '&#x222B;' },
     'Ι' => {:html => '&Iota;'      , :dec => '&#921;'  , :hex => '&#x0399;' },
     'ι' => {:html => '&iota;'      , :dec => '&#953;'  , :hex => '&#x03B9;' },
     '¿' => {:html => '&iquest;'    , :dec => '&#191;'  , :hex => '&#x00BF;' },
     '∈' => {:html => '&isin;'      , :dec => '&#8712;' , :hex => '&#x2208;' },
     'Ï' => {:html => '&Iuml;'      , :dec => '&#207;'  , :hex => '&#x00CF;' },
     'ï' => {:html => '&iuml;'      , :dec => '&#239;'  , :hex => '&#x00EF;' },
     'Κ' => {:html => '&Kappa;'     , :dec => '&#922;'  , :hex => '&#x039A;' },
     'κ' => {:html => '&kappa;'     , :dec => '&#954;'  , :hex => '&#x03BA;' },
     'Λ' => {:html => '&Lambda;'    , :dec => '&#923;'  , :hex => '&#x039B;' },
     'λ' => {:html => '&lambda;'    , :dec => '&#955;'  , :hex => '&#x03BB;' },
     '⟨' => {:html => '&lang;'      , :dec => '&#9001;' , :hex => '&#x2329;' },
     '«' => {:html => '&laquo;'     , :dec => '&#171;'  , :hex => '&#x00AB;' },
     '⇐' => {:html => '&lArr;'      , :dec => '&#8656;' , :hex => '&#x21D0;' },
     '←' => {:html => '&larr;'      , :dec => '&#8592;' , :hex => '&#x2190;' },
     '⌈' => {:html => '&lceil;'     , :dec => '&#8968;' , :hex => '&#x2308;' },
     '“' => {:html => '&ldquo;'     , :dec => '&#8220;' , :hex => '&#x201C;' },
     '≤' => {:html => '&le;'        , :dec => '&#8804;' , :hex => '&#x2264;' },
     '⌊' => {:html => '&lfloor;'    , :dec => '&#8970;' , :hex => '&#x230A;' },
     '∗' => {:html => '&lowast;'    , :dec => '&#8727;' , :hex => '&#x2217;' },
     '◊' => {:html => '&loz;'       , :dec => '&#9674;' , :hex => '&#x25CA;' },
     '‹' => {:html => '&lsaquo;'    , :dec => '&#8249;' , :hex => '&#x2039;' },
     '‘' => {:html => '&lsquo;'     , :dec => '&#8216;' , :hex => '&#x2018;' },
     '¯' => {:html => '&macr;'      , :dec => '&#175;'  , :hex => '&#x00AF;' },
     '—' => {:html => '&mdash;'     , :dec => '&#8212;' , :hex => '&#x2014;' },
     'µ' => {:html => '&micro;'     , :dec => '&#181;'  , :hex => '&#x00B5;' },
     '·' => {:html => '&middot;'    , :dec => '&#183;'  , :hex => '&#x00B7;' },
     '−' => {:html => '&minus;'     , :dec => '&#8722;' , :hex => '&#x2212;' },
     'Μ' => {:html => '&Mu;'        , :dec => '&#924;'  , :hex => '&#x039C;' },
     'μ' => {:html => '&mu;'        , :dec => '&#956;'  , :hex => '&#x03BC;' },
     '∇' => {:html => '&nabla;'     , :dec => '&#8711;' , :hex => '&#x2207;' },
     '–' => {:html => '&ndash;'     , :dec => '&#8211;' , :hex => '&#x2013;' },
     '≠' => {:html => '&ne;'        , :dec => '&#8800;' , :hex => '&#x2260;' },
     '∋' => {:html => '&ni;'        , :dec => '&#8715;' , :hex => '&#x220B;' },
     '¬' => {:html => '&not;'       , :dec => '&#172;'  , :hex => '&#x00AC;' },
     '∉' => {:html => '&notin;'     , :dec => '&#8713;' , :hex => '&#x2209;' },
     '⊄' => {:html => '&nsub;'      , :dec => '&#8836;' , :hex => '&#x2284;' },
     'Ñ' => {:html => '&Ntilde;'    , :dec => '&#209;'  , :hex => '&#x00D1;' },
     'ñ' => {:html => '&ntilde;'    , :dec => '&#241;'  , :hex => '&#x00F1;' },
     'Ν' => {:html => '&Nu;'        , :dec => '&#925;'  , :hex => '&#x039D;' },
     'ν' => {:html => '&nu;'        , :dec => '&#957;'  , :hex => '&#x03BD;' },
     'Ó' => {:html => '&Oacute;'    , :dec => '&#211;'  , :hex => '&#x00D3;' },
     'ó' => {:html => '&oacute;'    , :dec => '&#243;'  , :hex => '&#x00F3;' },
     'Ô' => {:html => '&Ocirc;'     , :dec => '&#212;'  , :hex => '&#x00D4;' },
     'ô' => {:html => '&ocirc;'     , :dec => '&#244;'  , :hex => '&#x00F4;' },
     'Œ' => {:html => '&OElig;'     , :dec => '&#338;'  , :hex => '&#x0152;' },
     'œ' => {:html => '&oelig;'     , :dec => '&#339;'  , :hex => '&#x0153;' },
     'Ò' => {:html => '&Ograve;'    , :dec => '&#210;'  , :hex => '&#x00D2;' },
     'ò' => {:html => '&ograve;'    , :dec => '&#242;'  , :hex => '&#x00F2;' },
     '‾' => {:html => '&oline;'     , :dec => '&#8254;' , :hex => '&#x203E;' },
     'Ω' => {:html => '&Omega;'     , :dec => '&#937;'  , :hex => '&#x03A9;' },
     'ω' => {:html => '&omega;'     , :dec => '&#969;'  , :hex => '&#x03C9;' },
     'Ο' => {:html => '&Omicron;'   , :dec => '&#927;'  , :hex => '&#x039F;' },
     'ο' => {:html => '&omicron;'   , :dec => '&#959;'  , :hex => '&#x03BF;' },
     '⊕' => {:html => '&oplus;'     , :dec => '&#8853;' , :hex => '&#x2295;' },
     '∨' => {:html => '&or;'        , :dec => '&#8744;' , :hex => '&#x2228;' },
     'ª' => {:html => '&ordf;'      , :dec => '&#170;'  , :hex => '&#x00AA;' },
     'º' => {:html => '&ordm;'      , :dec => '&#186;'  , :hex => '&#x00BA;' },
     'Ø' => {:html => '&Oslash;'    , :dec => '&#216;'  , :hex => '&#x00D8;' },
     'ø' => {:html => '&oslash;'    , :dec => '&#248;'  , :hex => '&#x00F8;' },
     'Õ' => {:html => '&Otilde;'    , :dec => '&#213;'  , :hex => '&#x00D5;' },
     'õ' => {:html => '&otilde;'    , :dec => '&#245;'  , :hex => '&#x00F5;' },
     '⊗' => {:html => '&otimes;'    , :dec => '&#8855;' , :hex => '&#x2297;' },
     'Ö' => {:html => '&Ouml;'      , :dec => '&#214;'  , :hex => '&#x00D6;' },
     'ö' => {:html => '&ouml;'      , :dec => '&#246;'  , :hex => '&#x00F6;' },
     '¶' => {:html => '&para;'      , :dec => '&#182;'  , :hex => '&#x00B6;' },
     '∂' => {:html => '&part;'      , :dec => '&#8706;' , :hex => '&#x2202;' },
     '‰' => {:html => '&permil;'    , :dec => '&#8240;' , :hex => '&#x2030;' },
     '⊥' => {:html => '&perp;'      , :dec => '&#8869;' , :hex => '&#x22A5;' },
     'Φ' => {:html => '&Phi;'       , :dec => '&#934;'  , :hex => '&#x03A6;' },
     'φ' => {:html => '&phi;'       , :dec => '&#966;'  , :hex => '&#x03C6;' },
     'Π' => {:html => '&Pi;'        , :dec => '&#928;'  , :hex => '&#x03A0;' },
     'π' => {:html => '&pi;'        , :dec => '&#960;'  , :hex => '&#x03C0;' },
     'ϖ' => {:html => '&piv;'       , :dec => '&#982;'  , :hex => '&#x03D6;' },
     '±' => {:html => '&plusmn;'    , :dec => '&#177;'  , :hex => '&#x00B1;' },
     '£' => {:html => '&pound;'     , :dec => '&#163;'  , :hex => '&#x00A3;' },
     '″' => {:html => '&Prime;'     , :dec => '&#8243;' , :hex => '&#x2033;' },
     '′' => {:html => '&prime;'     , :dec => '&#8242;' , :hex => '&#x2032;' },
     '∏' => {:html => '&prod;'      , :dec => '&#8719;' , :hex => '&#x220F;' },
     '∝' => {:html => '&prop;'      , :dec => '&#8733;' , :hex => '&#x221D;' },
     'Ψ' => {:html => '&Psi;'       , :dec => '&#936;'  , :hex => '&#x03A8;' },
     'ψ' => {:html => '&psi;'       , :dec => '&#968;'  , :hex => '&#x03C8;' },
     '√' => {:html => '&radic;'     , :dec => '&#8730;' , :hex => '&#x221A;' },
     '⟩' => {:html => '&rang;'      , :dec => '&#9002;' , :hex => '&#x232A;' },
     '»' => {:html => '&raquo;'     , :dec => '&#187;'  , :hex => '&#x00BB;' },
     '⇒' => {:html => '&rArr;'      , :dec => '&#8658;' , :hex => '&#x21D2;' },
     '→' => {:html => '&rarr;'      , :dec => '&#8594;' , :hex => '&#x2192;' },
     '⌉' => {:html => '&rceil;'     , :dec => '&#8969;' , :hex => '&#x2309;' },
     '”' => {:html => '&rdquo;'     , :dec => '&#8221;' , :hex => '&#x201D;' },
     'ℜ' => {:html => '&real;'      , :dec => '&#8476;' , :hex => '&#x211C;' },
     '®' => {:html => '&reg;'       , :dec => '&#174;'  , :hex => '&#x00AE;' },
     '⌋' => {:html => '&rfloor;'    , :dec => '&#8971;' , :hex => '&#x230B;' },
     'Ρ' => {:html => '&Rho;'       , :dec => '&#929;'  , :hex => '&#x03A1;' },
     'ρ' => {:html => '&rho;'       , :dec => '&#961;'  , :hex => '&#x03C1;' },
     '›' => {:html => '&rsaquo;'    , :dec => '&#8250;' , :hex => '&#x203A;' },
     '’' => {:html => '&rsquo;'     , :dec => '&#8217;' , :hex => '&#x2019;' },
     '‚' => {:html => '&sbquo;'     , :dec => '&#8218;' , :hex => '&#x201A;' },
     'Š' => {:html => '&Scaron;'    , :dec => '&#352;'  , :hex => '&#x0160;' },
     'š' => {:html => '&scaron;'    , :dec => '&#353;'  , :hex => '&#x0161;' },
     '⋅' => {:html => '&sdot;'      , :dec => '&#8901;' , :hex => '&#x22C5;' },
     '§' => {:html => '&sect;'      , :dec => '&#167;'  , :hex => '&#x00A7;' },
     'Σ' => {:html => '&Sigma;'     , :dec => '&#931;'  , :hex => '&#x03A3;' },
     'σ' => {:html => '&sigma;'     , :dec => '&#963;'  , :hex => '&#x03C3;' },
     'ς' => {:html => '&sigmaf;'    , :dec => '&#962;'  , :hex => '&#x03C2;' },
     '∼' => {:html => '&sim;'       , :dec => '&#8764;' , :hex => '&#x223C;' },
     '♠' => {:html => '&spades;'    , :dec => '&#9824;' , :hex => '&#x2660;' },
     '⊂' => {:html => '&sub;'       , :dec => '&#8834;' , :hex => '&#x2282;' },
     '⊆' => {:html => '&sube;'      , :dec => '&#8838;' , :hex => '&#x2286;' },
     '∑' => {:html => '&sum;'       , :dec => '&#8721;' , :hex => '&#x2211;' },
     '⊃' => {:html => '&sup;'       , :dec => '&#8835;' , :hex => '&#x2283;' },
     '¹' => {:html => '&sup1;'      , :dec => '&#185;'  , :hex => '&#x00B9;' },
     '²' => {:html => '&sup2;'      , :dec => '&#178;'  , :hex => '&#x00B2;' },
     '³' => {:html => '&sup3;'      , :dec => '&#179;'  , :hex => '&#x00B3;' },
     '⊇' => {:html => '&supe;'      , :dec => '&#8839;' , :hex => '&#x2287;' },
     'ß' => {:html => '&szlig;'     , :dec => '&#223;'  , :hex => '&#x00DF;' },
     'Τ' => {:html => '&Tau;'       , :dec => '&#932;'  , :hex => '&#x03A4;' },
     'τ' => {:html => '&tau;'       , :dec => '&#964;'  , :hex => '&#x03C4;' },
     '∴' => {:html => '&there4;'    , :dec => '&#8756;' , :hex => '&#x2234;' },
     'Θ' => {:html => '&Theta;'     , :dec => '&#920;'  , :hex => '&#x0398;' },
     'θ' => {:html => '&theta;'     , :dec => '&#952;'  , :hex => '&#x03B8;' },
     'ϑ' => {:html => '&thetasym;'  , :dec => '&#977;'  , :hex => '&#x03D1;' },
     'Þ' => {:html => '&THORN;'     , :dec => '&#222;'  , :hex => '&#x00DE;' },
     'þ' => {:html => '&thorn;'     , :dec => '&#254;'  , :hex => '&#x00FE;' },
     '˜' => {:html => '&tilde;'     , :dec => '&#732;'  , :hex => '&#x02DC;' },
     '×' => {:html => '&times;'     , :dec => '&#215;'  , :hex => '&#x00D7;' },
     '™' => {:html => '&trade;'     , :dec => '&#8482;' , :hex => '&#x2122;' },
     'Ú' => {:html => '&Uacute;'    , :dec => '&#218;'  , :hex => '&#x00DA;' },
     'ú' => {:html => '&uacute;'    , :dec => '&#250;'  , :hex => '&#x00FA;' },
     '⇑' => {:html => '&uArr;'      , :dec => '&#8657;' , :hex => '&#x21D1;' },
     '↑' => {:html => '&uarr;'      , :dec => '&#8593;' , :hex => '&#x2191;' },
     'Û' => {:html => '&Ucirc;'     , :dec => '&#219;'  , :hex => '&#x00DB;' },
     'û' => {:html => '&ucirc;'     , :dec => '&#251;'  , :hex => '&#x00FB;' },
     'Ù' => {:html => '&Ugrave;'    , :dec => '&#217;'  , :hex => '&#x00D9;' },
     'ù' => {:html => '&ugrave;'    , :dec => '&#249;'  , :hex => '&#x00F9;' },
     '¨' => {:html => '&uml;'       , :dec => '&#168;'  , :hex => '&#x00A8;' },
     'ϒ' => {:html => '&upsih;'     , :dec => '&#978;'  , :hex => '&#x03D2;' },
     'Υ' => {:html => '&Upsilon;'   , :dec => '&#933;'  , :hex => '&#x03A5;' },
     'υ' => {:html => '&upsilon;'   , :dec => '&#965;'  , :hex => '&#x03C5;' },
     'Ü' => {:html => '&Uuml;'      , :dec => '&#220;'  , :hex => '&#x00DC;' },
     'ü' => {:html => '&uuml;'      , :dec => '&#252;'  , :hex => '&#x00FC;' },
     '℘' => {:html => '&weierp;'    , :dec => '&#8472;' , :hex => '&#x2118;' },
     'Ξ' => {:html => '&Xi;'        , :dec => '&#926;'  , :hex => '&#x039E;' },
     'ξ' => {:html => '&xi;'        , :dec => '&#958;'  , :hex => '&#x03BE;' },
     'Ý' => {:html => '&Yacute;'    , :dec => '&#221;'  , :hex => '&#x00DD;' },
     'ý' => {:html => '&yacute;'    , :dec => '&#253;'  , :hex => '&#x00FD;' },
     '¥' => {:html => '&yen;'       , :dec => '&#165;'  , :hex => '&#x00A5;' },
     'Ÿ' => {:html => '&Yuml;'      , :dec => '&#376;'  , :hex => '&#x0178;' },
     'ÿ' => {:html => '&yuml;'      , :dec => '&#255;'  , :hex => '&#x00FF;' },
     'Ζ' => {:html => '&Zeta;'      , :dec => '&#918;'  , :hex => '&#x0396;' },
     'ζ' => {:html => '&zeta;'      , :dec => '&#950;'  , :hex => '&#x03B6;' }
   }
   
   
end
